@@ -13,7 +13,7 @@
 
 from abc import ABCMeta, abstractmethod
 #import jsonpath_rw_ext as jp
-from krules_core.arg_processors import processors
+from krules_core.arg_processors import processors, DefaultArgProcessor
 
 
 # class with_payload(object):
@@ -84,38 +84,33 @@ class RuleFunctionBase:
     type = ""
 
     def __init__(self, *args, **kwargs):
-        self._args = args
-        self._kwargs = kwargs
+        self._args = []
+        for a in args:
+            self._args.append(self._get_arg_processor(a))
+
+        self._kwargs = {}
+        for k, v in kwargs.items():
+            self._kwargs[k] = self._get_arg_processor(v)
+
+    @staticmethod
+    def _get_arg_processor(arg):
+        for processor in processors:
+            if processor.interested_in(arg):
+                return processor(arg)
+        return DefaultArgProcessor(arg)
 
     def _get_args(self, instance):
-
-        args = list(self._args)
-        for i in range(len(self._args)):
-            v = self._args[i]
-            for processor in processors:
-                if processor.interested_in(v):
-                #if processor.interested_in(self._args[i]):
-                    args[i] = processor.process(instance, v)
-                    #self._args[i] = processor.process(instance, v)
-                    break
-                else:
-                    pass
-        return args
+        args = []
+        for processor in self._args:
+            args.append(processor.process(instance))
+        return tuple(args)
 
     def _get_kwargs(self, instance):
-
-        kwargs = self._kwargs.copy()
-        for key in kwargs:
-            for processor in processors:
-                if processor.interested_in(kwargs[key]):
-                #if processor.interested_in(self._kwargs[key]):
-                    kwargs[key] = processor.process(instance, kwargs[key])
-                    break
-                else:
-                    pass
+        kwargs = {}
+        for key, processor in self._kwargs.items():
+            kwargs[key] = processor.process(instance)
         return kwargs
 
-
     @abstractmethod
     def execute(self, *args, **kwargs):
         raise NotImplementedError("execute")
