@@ -9,8 +9,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+
 class BaseDispatcher(object):
 
-    def dispatch(self, message, subject, payload, **extra):
+    def dispatch(self, type, subject, payload, **extra):
         from .router import logger
-        logger.debug("dispatch: {} {} {} | extra: {}".format(message, subject, payload, extra))
+        logger.debug("dispatch: {} {} {} | extra: {}".format(type, subject, payload, extra))
